#!/usr/bin/python3

import pygame
from ._any_widget import any_widget


class Container:
    """
    A Container is a widget similar to a <div> in HTML.
    It can contain other widgets and is used for responsive design.
    """

    def __init__(
            self,
            parent: any_widget | None=None,
            position: any=(0, 0),
            size: any=(100, 100),
            surface: pygame.Surface=None,
            layout: "ContainerLayout"=None
    ):
        self.parent = parent
        self.position = position
        self.size = size
        self.surface = surface
        self.layout = layout

        self.widgets = []

    def update(self):
        for widget in self.widgets:  # update all child widgets
            widget.update()

    def draw(self, surface: pygame.Surface):
        """
        Draw all child widgets and the container's surface.

        :param pygame.Surface surface: The surface to draw on.
        """

        if not self.surface is None:
            surface.blit(self.surface, self.position)

        for widget in self.widgets:  # draw all child widgets
            widget.draw(surface)
